pub enum WindowsFirewallError {
CoInitializeExFailed(String),
WindowsError(Error),
RuleAlreadyExists,
InvalidNetFwAction,
InvalidNetFwProfile,
InvalidNetFwRuleDirection,
InvalidNetFwIpProtocol,
EmptyHashSet,
}Expand description
Deriving common traits to automatically implement error handling functionality.
Variants
CoInitializeExFailed(String)
Error returned when CoInitializeEx fails during COM initialization.
WindowsError(Error)
A general Windows API error wrapped from the windows_result crate.
RuleAlreadyExists
Indicates that the specified firewall rule already exists.
InvalidNetFwAction
Indicates that an invalid value was used for NET_FW_ACTION.
InvalidNetFwProfile
Indicates that an invalid value was used for NET_FW_PROFILE.
InvalidNetFwRuleDirection
Indicates that an invalid value was used for NET_FW_RULE_DIRECTION.
InvalidNetFwIpProtocol
Indicates that an invalid value was used for NET_FW_IP_PROTOCOL.
EmptyHashSet
Indicates that a required HashSet is either empty or None.